Welcome to Django PyNotify's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   extra_tips
   configuration
   example_project
   reference
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
